==> haskell-hspec-2.4.3-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec
version: 2.4.3
id: hspec-2.4.3-BUiV4MrxPEkDaPSXuzkgLx
key: hspec-2.4.3-BUiV4MrxPEkDaPSXuzkgLx
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell. It is inspired by
    the Ruby library RSpec. Some of Hspec'\''s distinctive features
    are:
    .
    * a friendly DSL for defining tests
    .
    * integration with QuickCheck, SmallCheck, and HUnit
    .
    * parallel test execution
    .
    * automatic discovery of test files
    .
    The Hspec Manual is at <http://hspec.github.io/>.
category: Testing
exposed: True
exposed-modules:
    Test.Hspec Test.Hspec.Core Test.Hspec.Discover
    Test.Hspec.Formatters Test.Hspec.HUnit Test.Hspec.QuickCheck
    Test.Hspec.Runner
hidden-modules: Paths_hspec
abi: 307897f1796765c9e1fc79a71f5dfd7e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-2.4.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-2.4.3
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/hspec-2.4.3
hs-libraries: HShspec-2.4.3-BUiV4MrxPEkDaPSXuzkgLx
depends:
    HUnit-1.6.0.0-FzD79SWxsfL7BH2Ung8YXe
    QuickCheck-2.9.2-3a8nWdLsV8cEn9LdMoftRm base-4.9.0.0
    call-stack-0.1.0-izRGIczcaH64KMRs1Wg8q
    hspec-core-2.4.3-351sCVxQ82zEBnxphJv1Br
    hspec-discover-2.4.3-82Xkyt8TwLKBeUNjio0xN7
    hspec-expectations-0.8.2-LiEkzoyhl0hJjydPrYgxwd
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html: /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-2.4.3-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec
version: 2.4.3
id: hspec-2.4.3-3YqiuQxDYNaFgAnF6HxFK5
key: hspec-2.4.3-3YqiuQxDYNaFgAnF6HxFK5
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell. It is inspired by
    the Ruby library RSpec. Some of Hspec'\''s distinctive features
    are:
    .
    * a friendly DSL for defining tests
    .
    * integration with QuickCheck, SmallCheck, and HUnit
    .
    * parallel test execution
    .
    * automatic discovery of test files
    .
    The Hspec Manual is at <http://hspec.github.io/>.
category: Testing
exposed: True
exposed-modules:
    Test.Hspec Test.Hspec.Core Test.Hspec.Discover
    Test.Hspec.Formatters Test.Hspec.HUnit Test.Hspec.QuickCheck
    Test.Hspec.Runner
hidden-modules: Paths_hspec
abi: e5ed7cd27bff0307f67491a3aa52a836
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-2.4.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-2.4.3
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/hspec-2.4.3
hs-libraries: HShspec-2.4.3-3YqiuQxDYNaFgAnF6HxFK5
depends:
    HUnit-1.6.0.0-FzD79SWxsfL7BH2Ung8YXe
    QuickCheck-2.9.2-3a8nWdLsV8cEn9LdMoftRm base-4.9.0.0
    call-stack-0.1.0-izRGIczcaH64KMRs1Wg8q
    hspec-core-2.4.3-9QEWWqcuOQ477wajab1a2t
    hspec-discover-2.4.3-82Xkyt8TwLKBeUNjio0xN7
    hspec-expectations-0.8.2-LiEkzoyhl0hJjydPrYgxwd
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html: /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
